@@ -2,6 +2,7 @@ from time import time
 
 
 def time_fun(problem, funct):
-    problem.start_time = time()
+    s = time()
     solution = funct(problem)
-    problem.add_solution(solution)
+    e = time() - s
+    return solution, e
